@@ -48,8 +48,11 @@ def handle_db_dict(db_dict: dict) -> dict:
     try:
         db_dict['id'] = str(db_dict['_id'])
         del db_dict['_id']
+        # 将日期格式的时间，转化为13位时间戳
         db_dict['creation_time'] = int(time.mktime(
             db_dict['creation_time'].timetuple())) * 1000
+        db_dict['update_time'] = int(time.mktime(
+            db_dict['update_time'].timetuple())) * 1000
         return db_dict
     except Exception as err:
         str_data = 'MongoDB 数据字典解析异常: {0}'.format(err)
